@@ -1,19 +1,20 @@
-from podcast_client.models import PodcastChannel
+from .celery import app
+from .models import PodcastChannel, PodcastItem
 
 
+@app.task
 def update_channel(slug, force_download=False):
     channel = PodcastChannel.objects.get(slug=slug)
     channel.update_channel(download=force_download)
 
 
+@app.task
 def update_all_channels(force_download=False):
     for channel in PodcastChannel.objects.all():
         channel.update_channel(download=force_download)
 
-try:
-    from celery.decorators import task
-except ImportError:
-    pass
-else:
-    update_channel = task(update_channel)
-    update_all_channels = task(update_all_channels)
+
+@app.task
+def download_file(item_id):
+    item = PodcastItem.objects.get(id=item_id)
+    item.download_file()
